@@ -16,7 +16,7 @@ REPO_ROOT = (THIS_DIR / "..").resolve()
 TSFPGA_PATH = REPO_ROOT / "tsfpga"
 TSFPGA_DOC = REPO_ROOT / "doc"
 TSFPGA_MODULES = REPO_ROOT / "modules"
-TSFPGA_TCL = THIS_DIR / "tcl"
+TSFPGA_TCL = THIS_DIR / "vivado" / "tcl"
 TSFPGA_GENERATED = REPO_ROOT / "generated"
 
 TSFPGA_EXAMPLES = REPO_ROOT / "examples"
@@ -25,4 +25,4 @@ TSFPGA_EXAMPLE_MODULES_WITH_IP = TSFPGA_EXAMPLES / "modules_with_ip"
 
 ALL_TSFPGA_MODULES_FOLDERS = [TSFPGA_MODULES, TSFPGA_EXAMPLE_MODULES, TSFPGA_EXAMPLE_MODULES_WITH_IP]
 
-__version__ = "3.0.0"
+__version__ = "4.0.1"
