@@ -4,4 +4,4 @@
 
 # pylint: disable=wildcard-import
 
-from tsfpga.test.test_utils import *
+from .test_utils import *
