@@ -66,8 +66,11 @@ def test_can_cast_to_string_without_error():
     str(BaseModule(Path("dummy"), "dummy"))
 
 
-def test_generics_to_string():
-    assert BaseModule.generics_to_string(dict(apa=3, hest_zebra="foo")) == "apa_3.hest_zebra_foo"
+def test_test_case_name():
+    assert BaseModule.test_case_name(
+        generics=dict(apa=3, hest_zebra="foo")) == "apa_3.hest_zebra_foo"
+    assert BaseModule.test_case_name(
+        name="foo", generics=dict(apa=3, hest_zebra="bar")) == "foo.apa_3.hest_zebra_bar"
 
 
 @pytest.mark.usefixtures("fixture_tmp_path")
@@ -134,38 +137,38 @@ class Module(BaseModule):
             else:
                 assert False
 
-    @mock.patch("tsfpga.module.from_json", autospec=True)
-    def test_register_object_creation_synthesis(self, from_json):
-        json_file = create_file(self.tmp_path / "a" / "regs_a.json")
+    @mock.patch("tsfpga.module.from_toml", autospec=True)
+    def test_register_object_creation_synthesis(self, from_toml):
+        toml_file = create_file(self.tmp_path / "a" / "regs_a.toml")
 
         module = get_modules(self.modules_folders, names_include=["a"])[0]
         module.get_synthesis_files()
         module.get_synthesis_files()
 
-        from_json.assert_called_once_with("a", json_file, mock.ANY)
+        from_toml.assert_called_once_with("a", toml_file, mock.ANY)
 
-    @mock.patch("tsfpga.module.from_json", autospec=True)
-    def test_register_object_creation_simulation(self, from_json):
-        json_file = create_file(self.tmp_path / "a" / "regs_a.json")
+    @mock.patch("tsfpga.module.from_toml", autospec=True)
+    def test_register_object_creation_simulation(self, from_toml):
+        toml_file = create_file(self.tmp_path / "a" / "regs_a.toml")
 
         module = get_modules(self.modules_folders, names_include=["a"])[0]
         module.get_simulation_files()
         module.get_simulation_files()
 
-        from_json.assert_called_once_with("a", json_file, mock.ANY)
+        from_toml.assert_called_once_with("a", toml_file, mock.ANY)
 
-    @mock.patch("tsfpga.module.from_json", autospec=True)
-    def test_register_object_creation_mixed(self, from_json):
-        json_file = create_file(self.tmp_path / "a" / "regs_a.json")
+    @mock.patch("tsfpga.module.from_toml", autospec=True)
+    def test_register_object_creation_mixed(self, from_toml):
+        toml_file = create_file(self.tmp_path / "a" / "regs_a.toml")
 
         module = get_modules(self.modules_folders, names_include=["a"])[0]
         module.get_synthesis_files()
         module.get_simulation_files()
 
-        from_json.assert_called_once_with("a", json_file, mock.ANY)
+        from_toml.assert_called_once_with("a", toml_file, mock.ANY)
 
-    def test_deprecated_register_json_file_name_should_raise_exception(self):
-        json_file = create_file(self.tmp_path / "a" / "a_regs.json")
+    def test_deprecated_register_json_file_should_raise_exception(self):
+        json_file = create_file(self.tmp_path / "a" / "regs_a.json")
 
         module = get_modules(self.modules_folders, names_include=["a"])[0]
         with pytest.raises(ValueError) as exception_info:
